package TiVo::Web::Pages;

use strict;
use TiVo::Config;
use TiVo::Web::Page;
use Carp;

our $VERSION = 
    (split / /, q$Id: Pages.pm,v 1.5 2001/12/02 11:32:31 grant Exp $)[2];

sub new {
    my $class = shift;
    my $self = {};
    bless $self, $class;
    $self->{pages} = [];
    $self->_init(@_);
    return $self;
}

sub _init {
    my $self = shift;
    my %args = @_;

    my $conf = TiVo::Config->new;
    my $guide = $conf->guidedir;
    my @days = $args{days} ? @{$args{days}} : sorted_filenames("$guide/pages");

    for my $day (@days) {
        warn("day not found, skipping\n"), next unless -e "$guide/pages/$day";
        my @alldays = sorted_filenames("$guide/pages/$day");
        my @stations = $args{stations} ? @{$args{stations}} : @alldays;
        for my $station (@stations) {
            next unless -e "$guide/pages/$day/$station";
            my $page = TiVo::Web::Page->new;
            $page->day($day);
            $page->station($station);
            $page->load;
            push @{$self->{pages}}, $page;
        }
    }
}

# returns a list of TiVo::Web::Page objects
sub all {
    my $self = shift;
    return @{$self->{pages}};
}

sub sorted_filenames {
    my $dir = shift;
    opendir(DIR, $dir) or confess "failed opendir of $dir ($!)";
    my @files = sort({ $a <=> $b } 
                     grep(!/^\.\.?$/, readdir(DIR)));
    closedir(DIR) or confess "failed closedir of $dir ($!)";
    return @files;
}

1;
